elephant.test.test_sta module — Elephant 0.5.0 documentation

# elephant.test.test_sta module

Tests for the function sta module

class `elephant.test.test_sta.` `sfc_TestCase_new_scipy`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_incompatible_spiketrain_analogsignal`()
  `test_non_binned_spiketrain_input`()
  `test_non_matching_input_binning`()
  `test_output_frequencies`()
  `test_short_spiketrain`()
  `test_signal_dimensions`()
  `test_spike_field_coherence_perfect_coherence`()
  `test_start_stop_times_out_of_range`()
  `test_wrong_input_type`()

class `elephant.test.test_sta.` `sfc_TestCase_old_scipy`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()

class `elephant.test.test_sta.` `sta_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_all_spiketrains_empty`()
  `test_analog_signal_of_wrong_type`()

    Analog signal given as list, but must be AnalogSignal

  `test_empty_analogsignal`()
  `test_forgotten_AnalogSignal_argument`()
  `test_impossible_window`()
  `test_more_spiketrains_than_analogsignals_forbidden`()
  `test_one_smaller_nrspiketrains_smaller_nranalogsignals`()

    Number of spiketrains between 1 and number of analogsignals

  `test_one_spiketrain_empty`()

    Test for one empty SpikeTrain, but existing spikes in other

  `test_only_one_spike`()

    The output should be the same as the input

  `test_spike_earlier_than_analogsignal`()
  `test_spike_later_than_analogsignal`()
  `test_spike_triggered_average_with_n_spikes_on_constant_function`()

    Signal should average to the input

  `test_spike_triggered_average_with_shifted_sin_wave`()

    Signal should average to zero

  `test_spiketrain_of_list_type_in_wrong_sense`()
  `test_spiketrain_of_nonlist_and_nonspiketrain_type`()
  `test_usage_of_spikes`()
  `test_window_borders_as_complex_numbers`()
  `test_window_larger_than_signal`()
  `test_wrong_window_endtime_unit`()
  `test_wrong_window_starttime_unit`()